@@ -8,7 +8,7 @@ our @ISA = qw(Exporter);
 our @EXPORT_OK   = qw(rxlsx1D rxlsx2D wxlsx1D wxlsx2D);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 use Config;
 use constant DEBUG => $ENV{PDL_IO_XLSX_DEBUG} ? 1 : 0;
@@ -69,11 +69,11 @@ sub wxlsx1D {
   my @c_bad;
 
   my %alias = (
-    '%Y-%m-%d'              => [ 10, 'yyyy\-mm\-dd' ],
+    '%Y-%m-%d'              => [ 11, 'yyyy\-mm\-dd' ],
     '%Y-%m-%dT%H:%M'        => [ 16, 'yyyy\-mm\-dd\ hh:mm' ],
-    '%Y-%m-%dT%H:%M:%S'     => [ 19, 'yyyy\-mm\-dd\ hh:mm:ss' ],
-    '%Y-%m-%dT%H:%M:%S.%3N' => [ 23, 'yyyy\-mm\-dd\ hh:mm:ss.000' ],
-    '%Y-%m-%dT%H:%M:%S.%6N' => [ 23, 'yyyy\-mm\-dd\ hh:mm:ss.000' ],
+    '%Y-%m-%dT%H:%M:%S'     => [ 18, 'yyyy\-mm\-dd\ hh:mm:ss' ],
+    '%Y-%m-%dT%H:%M:%S.%3N' => [ 22, 'yyyy\-mm\-dd\ hh:mm:ss.000' ],
+    '%Y-%m-%dT%H:%M:%S.%6N' => [ 22, 'yyyy\-mm\-dd\ hh:mm:ss.000' ],
   );
 
   my $bad2empty = $O->{bad2empty};
@@ -503,7 +503,7 @@ sub _proc_wargs {
   my $O = { map { $_ => delete $C->{$_} } @keys };
   $O->{debug}     //= DEBUG;
   $O->{bad2empty} //= 1;
-  $O->{header}    //= ($fn eq '1D' ? 'auto' : undef); #XXX-TODO backport to PDL::IO::CSV
+  $O->{header}    //= ($fn eq '1D' ? 'auto' : undef);
 
   if (defined $O->{header}) {
     croak "FATAL: header should be arrayref" unless ref $O->{header} eq 'ARRAY' || $O->{header} eq 'auto';
@@ -533,8 +533,8 @@ sub _proc_rargs {
   my @keys = qw/ reshape_inc type debug empty2bad text2bad header sheet_name /;
   my $O = { map { $_ => delete $C->{$_} } @keys };
   $O->{reshape_inc} ||= 80_000;
-  $O->{type}        ||= ($fn eq '1D' ? 'auto' : double);  #XXX-TODO backport to PDL::IO::CSV
-  $O->{header}      ||= ($fn eq '1D' ? 'auto' : 0);       #XXX-TODO backport to PDL::IO::CSV
+  $O->{type}        ||= ($fn eq '1D' ? 'auto' : double);
+  $O->{header}      ||= ($fn eq '1D' ? 'auto' : 0);
   $O->{debug} = DEBUG unless defined $O->{debug};
 
   # empty2bad implies some PDL::IO::XLSX::Reader extra options
